@@ -22,7 +22,7 @@
  *
  * DSIG_Reference := Class for handling a DSIG reference element
  *
- * $Id: DSIGReference.cpp 1833341 2018-06-11 16:25:41Z scantor $
+ * $Id$
  *
  */
 
@@ -36,9 +36,7 @@
 #include <xsec/transformers/TXFMHash.hpp>
 #include <xsec/transformers/TXFMBase64.hpp>
 #include <xsec/transformers/TXFMSB.hpp>
-#include <xsec/transformers/TXFMXPath.hpp>
 #include <xsec/transformers/TXFMC14n.hpp>
-#include <xsec/transformers/TXFMXSL.hpp>
 #include <xsec/transformers/TXFMEnvelope.hpp>
 #include <xsec/dsig/DSIGConstants.hpp>
 #include <xsec/dsig/DSIGSignature.hpp>
