@@ -23,7 +23,7 @@
  * SimpleEncrypt := An application to generate an XML document (via Xerces) and encrypt
  *					a portion of it
  *
- * $Id: simpleDecrypt.cpp 1894293 2021-10-15 14:14:50Z scantor $
+ * $Id$
  *
  */
 
@@ -50,19 +50,6 @@
 
 #include "../utils/XSECDOMUtils.hpp"
 
-// Xalan
-
-#ifdef XSEC_HAVE_XALAN
-#include <xalanc/XalanTransformer/XalanTransformer.hpp>
-
-// If this isn't defined, we're on Xalan 1.12+ and require modern C++
-#ifndef XALAN_USING_XALAN
-# define XALAN_USING_XALAN(NAME) using xalanc :: NAME;
-#endif
-
-XALAN_USING_XALAN(XalanTransformer)
-#endif
-
 // OpenSSL
 
 XERCES_CPP_NAMESPACE_USE
@@ -117,9 +104,6 @@ int main (int argc, char **argv) {
 
 	try {
 		XMLPlatformUtils::Initialize();
-#ifdef XSEC_HAVE_XALAN
-		XalanTransformer::initialize();
-#endif
 		XSECPlatformUtils::Initialise();
 	}
 	catch (const XMLException &e) {
