@@ -23,7 +23,7 @@
  * SimpleEncrypt := An application to generate an XML document (via Xerces) and encrypt
  *					a portion of it
  *
- * $Id: simpleEncrypt.cpp 1894293 2021-10-15 14:14:50Z scantor $
+ * $Id$
  *
  */
 
@@ -46,15 +46,6 @@
 
 // Xalan
 
-#ifdef XSEC_HAVE_XALAN
-#include <xalanc/XalanTransformer/XalanTransformer.hpp>
-// If this isn't defined, we're on Xalan 1.12+ and require modern C++
-#ifndef XALAN_USING_XALAN
-# define XALAN_USING_XALAN(NAME) using xalanc :: NAME;
-#endif
-XALAN_USING_XALAN(XalanTransformer)
-#endif
-
 XERCES_CPP_NAMESPACE_USE
 
 DOMElement * g_toEncrypt;
@@ -119,9 +110,6 @@ int main (int argc, char **argv) {
 
 	try {
 		XMLPlatformUtils::Initialize();
-#ifdef XSEC_HAVE_XALAN
-		XalanTransformer::initialize();
-#endif
 		XSECPlatformUtils::Initialise();
 	}
 	catch (const XMLException &e) {
