@@ -45,17 +45,6 @@
 
 #include "../utils/XSECDOMUtils.hpp"
 
-// Xalan
-
-#ifdef XSEC_HAVE_XALAN
-#include <xalanc/XalanTransformer/XalanTransformer.hpp>
-// If this isn't defined, we're on Xalan 1.12+ and require modern C++
-#ifndef XALAN_USING_XALAN
-# define XALAN_USING_XALAN(NAME) using xalanc :: NAME;
-#endif
-XALAN_USING_XALAN(XalanTransformer)
-#endif
-
 XERCES_CPP_NAMESPACE_USE
 
 DOMDocument *createLetter(DOMImplementation *impl) {
@@ -97,9 +86,6 @@ int main (int argc, char **argv) {
 
 	try {
 		XMLPlatformUtils::Initialize();
-#ifdef XSEC_HAVE_XALAN
-		XalanTransformer::initialize();
-#endif
 		XSECPlatformUtils::Initialise();
 	}
 	catch (const XMLException &e) {
